//
//  AudioContentCommentListViewModel.swift
//  SodaLive
//
//  Created by klaus on 2023/08/13.
//

import Foundation
import Moya
import Combine

class AudioContentCommentListViewModel: ObservableObject {
    
    private let repository = ContentRepository()
    private var subscription = Set<AnyCancellable>()
    
    @Published var isLoading = false
    @Published var errorMessage = ""
    @Published var isShowPopup = false
    
    @Published var comment = ""
    @Published var totalCommentCount = 0
    @Published var commentList = [GetAudioContentCommentListItem]()
    
    var audioContentId = 0
    var page = 1
    var isLast = false
    private let pageSize = 10
    
    func getCommentList() {
        if (!isLast && !isLoading) {
            repository
                .getAudioContentCommentList(audioContentId: audioContentId, page: page, size: pageSize)
                .sink { result in
                    switch result {
                    case .finished:
                        DEBUG_LOG("finish")
                    case .failure(let error):
                        ERROR_LOG(error.localizedDescription)
                    }
                } receiveValue: { [unowned self] response in
                    let responseData = response.data
                    
                    do {
                        let jsonDecoder = JSONDecoder()
                        let decoded = try jsonDecoder.decode(ApiResponse<GetAudioContentCommentListResponse>.self, from: responseData)
                        
                        if let data = decoded.data, decoded.success {
                            if page == 1 {
                                commentList.removeAll()
                            }
                            
                            if !data.items.isEmpty {
                                page += 1
                                self.totalCommentCount = data.totalCount
                                self.commentList.append(contentsOf: data.items)
                            } else {
                                isLast = true
                            }
                        } else {
                            if let message = decoded.message {
                                self.errorMessage = message
                            } else {
                                self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                            }
                            
                            self.isShowPopup = true
                        }
                    } catch {
                        self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        self.isShowPopup = true
                    }
                    
                    self.isLoading = false
                }
                .store(in: &subscription)
        }
    }
    
    func registerComment() {
        if comment.trimmingCharacters(in: .whitespaces).isEmpty {
            return
        }
        
        isLoading = true
        
        repository.registerComment(audioContentId: audioContentId, comment: comment)
            .sink { result in
                switch result {
                case .finished:
                    DEBUG_LOG("finish")
                case .failure(let error):
                    ERROR_LOG(error.localizedDescription)
                }
            } receiveValue: { [unowned self] response in
                self.isLoading = false
                let responseData = response.data
                
                do {
                    let jsonDecoder = JSONDecoder()
                    let decoded = try jsonDecoder.decode(ApiResponseWithoutData.self, from: responseData)
                    
                    if decoded.success {
                        self.comment = ""
                        self.page = 1
                        self.isLast = false
                        self.getCommentList()
                    } else {
                        if let message = decoded.message {
                            self.errorMessage = message
                        } else {
                            self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        }
                        
                        self.isShowPopup = true
                    }
                } catch {
                    self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                    self.isShowPopup = true
                }
            }
            .store(in: &subscription)
    }
}
